@@ -1,6 +1,6 @@
 package Net::Riak::Role::REST::Search;
 {
-  $Net::Riak::Role::REST::Search::VERSION = '0.1700';
+  $Net::Riak::Role::REST::Search::VERSION = '0.1701';
 }
 use Moose::Role;
 use JSON;
@@ -76,6 +76,24 @@ sub setup_indexing {
     JSON::decode_json($http_response->content);
 }
 
+sub index {
+    my ($self, $bucket, $index, $first, $last) = @_;
+
+    my $request;
+    my @req = ();
+
+    my $org_prefix = $self->prefix;
+    if (defined $bucket && defined $index && defined $first) {
+        @req = ('buckets', $bucket, 'index', $index, $first);
+        push(@req, $last) if (defined $last);
+    }
+
+    $request = $self->new_request('GET', [ @req ]);
+
+    my $http_response = $self->send_request($request);
+    JSON::decode_json($http_response->content)->{keys};
+}
+
 1;
 
 __END__
@@ -88,7 +106,7 @@ Net::Riak::Role::REST::Search - Search interface
 
 =head1 VERSION
 
-version 0.1700
+version 0.1701
 
 =head1 AUTHOR
 
@@ -96,7 +114,7 @@ franck cuny <franck@lumberjaph.net>, robin edwards <robin.ge@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by linkfluence.
+This software is copyright (c) 2013 by linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
